Apply .clangformat to all repo source files

Change-Id: I7e79c6058f0303f9a98911e3b7dd2e8596079344


[ROCm/hip commit: 1ba06f63c4]
This commit is contained in:
Maneesh Gupta
2018-03-12 11:29:03 +05:30
والد 52506ef382
کامیت 4f42ee762d
293فایلهای تغییر یافته به همراه43980 افزوده شده و 45830 حذف شده
@@ -20,45 +20,44 @@ THE SOFTWARE.
/*
* Test for checking the functionality of
* hipError_t hipDeviceSynchronize();
*/
*/
#include "hip/hip_runtime.h"
#include<iostream>
#include <iostream>
#define _SIZE sizeof(int)*1024*1024
#define _SIZE sizeof(int) * 1024 * 1024
#define NUM_STREAMS 20
#define ITER 1<<10
#define ITER 1 << 10
__global__ void Iter(hipLaunchParm lp, int *Ad, int num){
__global__ void Iter(hipLaunchParm lp, int* Ad, int num) {
int tx = threadIdx.x + blockIdx.x * blockDim.x;
if(tx == 0){
for(int i = 0; i<num;i++){
if (tx == 0) {
for (int i = 0; i < num; i++) {
Ad[tx] += 1;
}
}
}
int main(){
int *A[NUM_STREAMS];
int *Ad[NUM_STREAMS];
int main() {
int* A[NUM_STREAMS];
int* Ad[NUM_STREAMS];
hipStream_t stream[NUM_STREAMS];
for(int i=0;i<NUM_STREAMS;i++){
for (int i = 0; i < NUM_STREAMS; i++) {
hipHostMalloc((void**)&A[i], _SIZE, hipHostMallocDefault);
A[i][0] = 1;
hipMalloc((void**)&Ad[i], _SIZE);
hipStreamCreate(&stream[i]);
}
for(int i=0;i<NUM_STREAMS;i++){
for(int j=0;j<ITER;j++){
std::cout<<"Iter: "<<j<<std::endl;
hipMemcpyAsync(Ad[i], A[i], _SIZE, hipMemcpyHostToDevice, stream[i]);
hipLaunchKernel(HIP_KERNEL_NAME(Iter), dim3(1), dim3(1), 0, stream[i], Ad[i], 1<<30);
hipMemcpyAsync(A[i], Ad[i], _SIZE, hipMemcpyDeviceToHost, stream[i]);
for (int i = 0; i < NUM_STREAMS; i++) {
for (int j = 0; j < ITER; j++) {
std::cout << "Iter: " << j << std::endl;
hipMemcpyAsync(Ad[i], A[i], _SIZE, hipMemcpyHostToDevice, stream[i]);
hipLaunchKernel(HIP_KERNEL_NAME(Iter), dim3(1), dim3(1), 0, stream[i], Ad[i], 1 << 30);
hipMemcpyAsync(A[i], Ad[i], _SIZE, hipMemcpyDeviceToHost, stream[i]);
}
}
std::cout<<"Waitin..."<<std::endl;
std::cout << "Waitin..." << std::endl;
hipDeviceSynchronize();
}
@@ -18,44 +18,44 @@ THE SOFTWARE.
*/
#include "hip/hip_runtime.h"
#include<iostream>
#include<time.h>
#include <iostream>
#include <time.h>
#define NUM_SIZE 8
#define NUM_ITER 1 << 30
static size_t size[NUM_SIZE];
__global__ void Add(hipLaunchParm lp, int *Ad){
__global__ void Add(hipLaunchParm lp, int* Ad) {
int tx = threadIdx.x;
Ad[tx] = Ad[tx] + tx;
}
void setup(){
for(int i=0;i<NUM_SIZE;i++){
size[i] = 1<<(i+6); // start at 8 bytes
void setup() {
for (int i = 0; i < NUM_SIZE; i++) {
size[i] = 1 << (i + 6); // start at 8 bytes
}
}
void valSet(int *A, int val, size_t size){
size_t len = size/sizeof(int);
for(int i=0;i<len;i++){
void valSet(int* A, int val, size_t size) {
size_t len = size / sizeof(int);
for (int i = 0; i < len; i++) {
A[i] = val;
}
}
int main(){
int main() {
setup();
int *A, *Ad;
for(int i=0;i<NUM_SIZE;i++){
for (int i = 0; i < NUM_SIZE; i++) {
A = (int*)malloc(size[i]);
valSet(A, 1, size[i]);
hipMalloc(&Ad, size[i]);
std::cout<<"Malloc success at size: "<<size[i]<<std::endl;
std::cout << "Malloc success at size: " << size[i] << std::endl;
for(int j=0;j<NUM_ITER;j++){
std::cout<<"Iter: "<<j<<std::endl;
for (int j = 0; j < NUM_ITER; j++) {
std::cout << "Iter: " << j << std::endl;
hipMemcpy(Ad, A, size[i], hipMemcpyHostToDevice);
hipLaunchKernel(Add, dim3(1), dim3(size[i]/sizeof(int)), 0, 0, Ad);
hipLaunchKernel(Add, dim3(1), dim3(size[i] / sizeof(int)), 0, 0, Ad);
hipMemcpy(A, Ad, size[i], hipMemcpyDeviceToHost);
}
@@ -18,47 +18,48 @@ THE SOFTWARE.
*/
#include "hip/hip_runtime.h"
#include<iostream>
#include<time.h>
#include <iostream>
#include <time.h>
#define NUM_SIZE 8
#define NUM_ITER 1 << 30
static size_t size[NUM_SIZE];
__global__ void Add(hipLaunchParm lp, int *Ad){
__global__ void Add(hipLaunchParm lp, int* Ad) {
int tx = threadIdx.x;
Ad[tx] = Ad[tx] + tx;
}
void setup(){
for(int i=0;i<NUM_SIZE;i++){
size[i] = 1<<(i+6); // start at 8 bytes
}
void setup() {
for (int i = 0; i < NUM_SIZE; i++) {
size[i] = 1 << (i + 6); // start at 8 bytes
}
}
void valSet(int *A, int val, size_t size){
size_t len = size/sizeof(int);
for(int i=0;i<len;i++){
A[i] = val;
}
void valSet(int* A, int val, size_t size) {
size_t len = size / sizeof(int);
for (int i = 0; i < len; i++) {
A[i] = val;
}
}
int main(){
setup();
int *A, *Ad;
for(int i=0;i<NUM_SIZE;i++){
A = (int*)malloc(size[i]);
valSet(A, 1, size[i]);
hipMalloc(&Ad, size[i]);
std::cout<<"Malloc success at size: "<<size[i]<<std::endl;
for(int j=0;j<NUM_ITER;j++){
std::cout<<"\r"<<"Iter: "<<j;
hipLaunchKernel(Add, dim3(1), dim3(size[i]/sizeof(int)), 0, 0, Ad);
}
std::cout<<std::endl;
hipDeviceSynchronize();
int main() {
setup();
int *A, *Ad;
for (int i = 0; i < NUM_SIZE; i++) {
A = (int*)malloc(size[i]);
valSet(A, 1, size[i]);
hipMalloc(&Ad, size[i]);
std::cout << "Malloc success at size: " << size[i] << std::endl;
for (int j = 0; j < NUM_ITER; j++) {
std::cout << "\r"
<< "Iter: " << j;
hipLaunchKernel(Add, dim3(1), dim3(size[i] / sizeof(int)), 0, 0, Ad);
}
std::cout << std::endl;
hipDeviceSynchronize();
free(A);
hipFree(Ad);
}
free(A);
hipFree(Ad);
}
}
@@ -18,39 +18,40 @@ THE SOFTWARE.
*/
#include "hip/hip_runtime.h"
#include<iostream>
#include<time.h>
#include <iostream>
#include <time.h>
#define NUM_SIZE 8
#define NUM_ITER 1 << 30
static size_t size[NUM_SIZE];
void setup(){
for(int i=0;i<NUM_SIZE;i++){
size[i] = 1<<(i+6); // start at 8 bytes
}
void setup() {
for (int i = 0; i < NUM_SIZE; i++) {
size[i] = 1 << (i + 6); // start at 8 bytes
}
}
void valSet(int *A, int val, size_t size){
size_t len = size/sizeof(int);
for(int i=0;i<len;i++){
A[i] = val;
}
void valSet(int* A, int val, size_t size) {
size_t len = size / sizeof(int);
for (int i = 0; i < len; i++) {
A[i] = val;
}
}
int main(){
setup();
int *A, *Ad;
for(int i=0;i<NUM_SIZE;i++){
A = (int*)malloc(size[i]);
valSet(A, 1, size[i]);
hipMalloc(&Ad, size[i]);
std::cout<<"Malloc success at size: "<<size[i]<<std::endl;
for(int j=0;j<NUM_ITER;j++){
std::cout<<"\r"<<"Iter: "<<j;
hipMemcpy(Ad, A, size[i], hipMemcpyHostToDevice);
}
std::cout<<std::endl;
hipDeviceSynchronize();
}
int main() {
setup();
int *A, *Ad;
for (int i = 0; i < NUM_SIZE; i++) {
A = (int*)malloc(size[i]);
valSet(A, 1, size[i]);
hipMalloc(&Ad, size[i]);
std::cout << "Malloc success at size: " << size[i] << std::endl;
for (int j = 0; j < NUM_ITER; j++) {
std::cout << "\r"
<< "Iter: " << j;
hipMemcpy(Ad, A, size[i], hipMemcpyHostToDevice);
}
std::cout << std::endl;
hipDeviceSynchronize();
}
}
@@ -20,44 +20,43 @@ THE SOFTWARE.
/*
* Test for checking the functionality of
* hipError_t hipDeviceSynchronize();
*/
*/
#include "hip/hip_runtime.h"
#include<iostream>
#include <iostream>
#define _SIZE sizeof(int)*1024*1024
#define _SIZE sizeof(int) * 1024 * 1024
#define NUM_STREAMS 20
#define ITER 1<<10
#define ITER 1 << 10
__global__ void Iter(hipLaunchParm lp, int *Ad, int num){
__global__ void Iter(hipLaunchParm lp, int* Ad, int num) {
int tx = threadIdx.x + blockIdx.x * blockDim.x;
if(tx == 0){
for(int i = 0; i<num;i++){
if (tx == 0) {
for (int i = 0; i < num; i++) {
Ad[tx] += 1;
}
}
}
int main(){
int *A[NUM_STREAMS];
int *Ad[NUM_STREAMS];
int main() {
int* A[NUM_STREAMS];
int* Ad[NUM_STREAMS];
hipStream_t stream[NUM_STREAMS];
for(int i=0;i<NUM_STREAMS;i++){
for (int i = 0; i < NUM_STREAMS; i++) {
hipHostMalloc((void**)&A[i], _SIZE, hipHostMallocDefault);
A[i][0] = 1;
hipMalloc((void**)&Ad[i], _SIZE);
}
for(int i=0;i<NUM_STREAMS;i++){
for(int j=0;j<ITER;j++){
std::cout<<"Iter: "<<j<<std::endl;
hipMemcpy(Ad[i], A[i], _SIZE, hipMemcpyHostToDevice);
hipLaunchKernel(HIP_KERNEL_NAME(Iter), dim3(1), dim3(1), 0, 0, Ad[i], 1<<30);
hipMemcpyAsync(A[i], Ad[i], _SIZE, hipMemcpyDeviceToHost);
for (int i = 0; i < NUM_STREAMS; i++) {
for (int j = 0; j < ITER; j++) {
std::cout << "Iter: " << j << std::endl;
hipMemcpy(Ad[i], A[i], _SIZE, hipMemcpyHostToDevice);
hipLaunchKernel(HIP_KERNEL_NAME(Iter), dim3(1), dim3(1), 0, 0, Ad[i], 1 << 30);
hipMemcpyAsync(A[i], Ad[i], _SIZE, hipMemcpyDeviceToHost);
}
}
std::cout<<"Waitin..."<<std::endl;
std::cout << "Waitin..." << std::endl;
hipDeviceSynchronize();
}